diff --git a/src/doc/administration.rst b/src/doc/administration.rst
index eab02e43a833559dc21ea7a9fa5edfaf6431facf..cb45058f209b82bc7cd993eaac59971ab7c45882 100644
--- a/src/doc/administration.rst
+++ b/src/doc/administration.rst
@@ -4,7 +4,7 @@ Administration
 The Python script ``caosdb_admin.py`` should be used for administrative tasks.
 Call ``caosdb_admin.py --help`` to see how to use it.
 
-The most common task is to create a new user (in the CaosDB realm) and set a 
+The most common task is to create a new user (in the LinkAhead realm) and set a
 password for the user (note that a user typically needs to be activated):
 
 .. code:: console
diff --git a/src/doc/concepts.rst b/src/doc/concepts.rst
index 29625a0a105dacdea2183eac743d1904a7743ec7..2438614f3b1fb8f1b392fef9a03f618dc1cf9750 100644
--- a/src/doc/concepts.rst
+++ b/src/doc/concepts.rst
@@ -1,6 +1,6 @@
-========================
-The concepts of PyCaosDB
-========================
+===========================
+The concepts of PyLinkAhead
+===========================
 
 - `Configuration <configuration>`
 
diff --git a/src/doc/configuration.md b/src/doc/configuration.md
index 02cbbd7b13d916a676ad26c277e370ae76bf3725..841582f6c3c92397ddef612d1bad315de64b45c4 100644
--- a/src/doc/configuration.md
+++ b/src/doc/configuration.md
@@ -1,6 +1,6 @@
-# Configuration of PyCaosDB #
-The behavior of PyCaosDB is defined via a configuration that is provided using configuration files.
-PyCaosDB tries to read from the inifile specified in the environment variable `PYCAOSDBINI` or
+# Configuration of PyLinkAhead #
+The behavior of PyLinkAhead is defined via a configuration that is provided using configuration files.
+PyLinkAhead tries to read from the inifile specified in the environment variable `PYCAOSDBINI` or
 alternatively in `~/.pycaosdb.ini` upon import.  After that, the ini file `pycaosdb.ini` in the
 current working directory will be read additionally, if it exists.
 
@@ -10,7 +10,7 @@ it as a starting point.
 
 
 Typically, you need to change at least the `url` and `username` fields as required.  (Ask your
-CaosDB administrator or IT crowd if you do not know what to put there, but for the demo instance at
+LinkAhead administrator or IT crowd if you do not know what to put there, but for the demo instance at
 https://demo.indiscale.com, `username=admin` and `password=caosdb` should work).
 
 ## Authentication ##
@@ -46,7 +46,7 @@ username=YOUR_USERNAME
 
 ## SSL Certificate ##
 
-In some cases (especially if you are testing CaosDB) you might need to supply an SSL certificate to
+In some cases (especially if you are testing LinkAhead) you might need to supply an SSL certificate to
 allow SSL encryption.
 
 The `cacert` option sets the path to the ssl certificate for the connection:
@@ -59,7 +59,7 @@ cacert=/path/to/caosdb.ca.pem
 ## Further Settings ##
 
 `debug=0` ensures that debug information is **not** printed to the terminal every time you interact
-with CaosDB which makes the experience much less verbose. Set it to 1 or 2 in case you want to help
+with LinkAhead which makes the experience much less verbose. Set it to 1 or 2 in case you want to help
 debugging (which I hope will not be necessary for this tutorial) or if you want to learn more about
 the internals of the protocol. 
 
diff --git a/src/doc/future_caosdb.md b/src/doc/future_linkahead.md
similarity index 96%
rename from src/doc/future_caosdb.md
rename to src/doc/future_linkahead.md
index de6170fa42674ed4e3161fb791a397a149dba659..3c3038fa4c16922a0c83dc425120a14c112cc4fa 100644
--- a/src/doc/future_caosdb.md
+++ b/src/doc/future_linkahead.md
@@ -1,4 +1,4 @@
-# The future of the CaosDB Python Client
+# The future of the LinkAhead Python Client
 
 The current Python client has done us great services but its structure and the 
 way it is used sometimes feels outdated and clumsy. In this document we sketch
@@ -47,7 +47,7 @@ function:
 -   `depth`: Maximum recursion depth
 -   `references`: Whether to use the supplied db.Container to resolve
     references. This allows offline usage. Set it to None if you want to
-    automatically retrieve entities from the current CaosDB connection.
+    automatically retrieve entities from the current LinkAhead connection.
 
 In order to allow a quick look at the object structures an easily readable 
 serialization is provided by the `to_dict` function. It has the following 
@@ -174,7 +174,7 @@ print("The new record has the ID:", inserted.id)
 ```
 
 ### Factory method
-While creating an Entity will not talk to a CaosDB server and can thus be done offline, the factory method
+While creating an Entity will not talk to a LinkAhead server and can thus be done offline, the factory method
 `create_record` allows to 
 1. Retrieve the parent and set attributes according to inheritance
 2. Use a container to resolve the parent and set attributes
diff --git a/src/doc/gallery/curator-permissions.rst b/src/doc/gallery/curator-permissions.rst
index fa6b4022b7fbc1d042ed00f265e63a2675794a21..b0101e0f723403ef4af75e356a58313b32d415e4 100644
--- a/src/doc/gallery/curator-permissions.rst
+++ b/src/doc/gallery/curator-permissions.rst
@@ -18,7 +18,7 @@ In the following, you'll learn how to
 Prerequisites
 -------------
 
-This example needs some preparations regarding your CaosDB setup that have to
+This example needs some preparations regarding your LinkAhead setup that have to
 (or, for the sake of simplicity, should) be done outside the actual Python
 example script.
 
@@ -61,7 +61,7 @@ Clone the schemata into the same directory containing the below script via
 
    $ git clone https://github.com/leibniz-zmt/zmt-metadata-schema.git
 
-Furthermore, we'll need the `CaosDB Advanced User Tools
+Furthermore, we'll need the `LinkAhead Advanced User Tools
 <https://gitlab.com/caosdb/caosdb-advanced-user-tools>`_ for loading the
 metadata schemata from the json files, so install them via
 
@@ -109,13 +109,13 @@ Your complete ``global_entities_permissions.xml`` might then look like
 
 .. note::
 
-   Note that you have to restart your CaosDB server after modifying the
+   Note that you have to restart your LinkAhead server after modifying the
    ``global_entities_permissions.xml``.
 
 The code
 --------
 
-After having applied all of the above prerequisites and restarting your CaosDB
+After having applied all of the above prerequisites and restarting your LinkAhead
 server, execute the following code.
 
 :download:`Download full code<curator_permissions.py>`
diff --git a/src/doc/gallery/index.rst b/src/doc/gallery/index.rst
index bfba4317c3556d0692eb402f42ba3699be586d5a..f3c6c699d110ca2927e75a4a37055a020b55918a 100644
--- a/src/doc/gallery/index.rst
+++ b/src/doc/gallery/index.rst
@@ -1,13 +1,13 @@
 
-PyCaosDB Code Gallery
-=====================
+PyLinkAhead Code Gallery
+========================
 
-This chapter collects code examples which can be immediately run against an empty CaosDB instance.
+This chapter collects code examples which can be immediately run against an empty LinkAhead instance.
 
 .. note::
 
    These examples require a configuration file with valid server and user/password settings.  Refer
-   to the :ref:`Configuration <Configuration of PyCaosDB>` section for details.
+   to the :ref:`Configuration <Configuration of PyLinkAhead>` section for details.
 
 .. toctree::
    :maxdepth: 2
diff --git a/src/doc/gallery/simulation.rst b/src/doc/gallery/simulation.rst
index ce1a7f457a142e36ef9f2b0cfe6a4df0b9fcedf6..887c6219d80b579bda50fff5cf6411798579228c 100644
--- a/src/doc/gallery/simulation.rst
+++ b/src/doc/gallery/simulation.rst
@@ -6,7 +6,7 @@ This code example
 
 1. sets up the data model
 2. runs simulations
-3. stores the simulation parameters and results into CaosDB
+3. stores the simulation parameters and results into LinkAhead
 4. retrieves the parameters for interesting results.
 
 :download:`Download code<simulation.py>`
diff --git a/src/doc/high_level_api.org b/src/doc/high_level_api.org
index 516df1b41d500fab000a72517fd2d12ba61753b7..e00c868ee6ffc7e84a587dd7654a7459a049ebb9 100644
--- a/src/doc/high_level_api.org
+++ b/src/doc/high_level_api.org
@@ -1,8 +1,8 @@
 * High Level API
 
 In addition to the old standard pylib API, new versions of pylib ship with a high level API
-that facilitates usage of CaosDB entities within data analysis scripts. In a nutshell that
-API exposes all properties of CaosDB Records as standard python attributes making their
+that facilitates usage of LinkAhead entities within data analysis scripts. In a nutshell that
+API exposes all properties of LinkAhead Records as standard python attributes making their
 access easier.
 
 Or to spell it out directly in Python:
@@ -38,9 +38,9 @@ Furthermore there are a few utility functions which expose very practical shorth
 - ~create_record~: Create a new high level entity using the name of a record type and a list of key value pairs as properties.
 - ~load_external_record~: Retrieve a record with a specific name and return it as high level entity.
 - ~create_entity_container~: Convert a high level entity into a standard entity including all sub entities.
-- ~query~: Do a CaosDB query and return the result as a container of high level objects.
+- ~query~: Do a LinkAhead query and return the result as a container of high level objects.
 
-So as a first example, you could retrieve any record from CaosDB and use it using its high level representation:
+So as a first example, you could retrieve any record from LinkAhead and use it using its high level representation:
 #+BEGIN_SRC python
   from caosdb.high_level_api import query
 
@@ -69,9 +69,9 @@ to achieve the same result:
 #+END_SRC
 
 Resolving subproperties makes use of the "resolve_reference" function provided by the high level
-entity class (~CaosDBPythonEntity~), with the following parameters:
+entity class (~LinkAheadPythonEntity~), with the following parameters:
 - ~deep~: Whether to use recursive retrieval
-- ~references~: Whether to use the supplied db.Container to resolve references. This allows offline usage. Set it to None if you want to automatically retrieve entities from the current CaosDB connection.
+- ~references~: Whether to use the supplied db.Container to resolve references. This allows offline usage. Set it to None if you want to automatically retrieve entities from the current LinkAhead connection.
 - ~visited~: Needed for recursion, set this to None.
 
 Objects in the high level representation can be serialized to a simple yaml form using the function
@@ -95,25 +95,25 @@ As described in the section [[Quickstart]] the two functions ~convert_to_python_
 entities beetween the high level and the standard representation.
 
 The high level entities are represented using the following classes from the module ~caosdb.high_level_api~:
-- ~CaosDBPythonEntity~: Base class of the following entity classes.
-- ~CaosDBPythonRecord~
-- ~CaosDBPythonRecordType~
-- ~CaosDBPythonProperty~
-- ~CaosDBPythonMultiProperty~: **WARNING** Not implemented yet.
-- ~CaosDBPythonFile~: Used for file entities and provides an additional ~download~ function for being able to directly retrieve files from CaosDB.
+- ~LinkAheadPythonEntity~: Base class of the following entity classes.
+- ~LinkAheadPythonRecord~
+- ~LinkAheadPythonRecordType~
+- ~LinkAheadPythonProperty~
+- ~LinkAheadPythonMultiProperty~: **WARNING** Not implemented yet.
+- ~LinkAheadPythonFile~: Used for file entities and provides an additional ~download~ function for being able to directly retrieve files from LinkAhead.
 
 In addition, there are the following helper structures which are realized as Python data classes:
-- ~CaosDBPropertyMetaData~: For storing meta data about properties.
-- ~CaosDBPythonUnresolved~: The base class of unresolved "things".
-- ~CaosDBPythonUnresolvedParent~: Parents of entities are stored as unresolved parents by default, storing an id or a name of a parent (or both).
-- ~CaosDBPythonUnresolvedReference~: An unresolved reference is a reference property with an id which has not (yet) been resolved to an Entity.
+- ~LinkAheadPropertyMetaData~: For storing meta data about properties.
+- ~LinkAheadPythonUnresolved~: The base class of unresolved "things".
+- ~LinkAheadPythonUnresolvedParent~: Parents of entities are stored as unresolved parents by default, storing an id or a name of a parent (or both).
+- ~LinkAheadPythonUnresolvedReference~: An unresolved reference is a reference property with an id which has not (yet) been resolved to an Entity.
 
-The function "resolve_references" can be used to recursively replace ~CaosDBPythonUnresolvedReferences~ into members of type ~CaosDBPythonRecords~
-or ~CaosDBPythonFile~.
+The function "resolve_references" can be used to recursively replace ~LinkAheadPythonUnresolvedReferences~ into members of type ~LinkAheadPythonRecords~
+or ~LinkAheadPythonFile~.
 
-Each property stored in a CaosDB record corresponds to:
-- a member attribute of ~CaosDBPythonRecord~ **and**
-- an entry in a dict called "metadata" storing a CaosDBPropertyMetadata object with the following information about proeprties:
+Each property stored in a LinkAhead record corresponds to:
+- a member attribute of ~LinkAheadPythonRecord~ **and**
+- an entry in a dict called "metadata" storing a LinkAheadPropertyMetadata object with the following information about proeprties:
   - ~unit~
   - ~datatype~
   - ~description~
@@ -166,6 +166,6 @@ Records are created by the `create_record` function. Parameter values can be set
 #+END_SRC
 
 At any position in the algorithm you are free to:
-- Convert this model to the standard python API and insert or update the records in a running instance of CaosDB.
-- Serialize this model in the high level API yaml format. This enables the CaosDB crawler to pickup the file and synchronize it with a running instance 
-of CaosDB.
+- Convert this model to the standard python API and insert or update the records in a running instance of LinkAhead.
+- Serialize this model in the high level API yaml format. This enables the LinkAhead crawler to pickup the file and synchronize it with a running instance 
+of LinkAhead.
diff --git a/src/doc/high_level_api.rst b/src/doc/high_level_api.rst
index e92f2dd5e326b14222ad3c776ce5f5ed1ed31536..2f4bc3cee96e2f8bc9a5e59f97b1f055ca428c56 100644
--- a/src/doc/high_level_api.rst
+++ b/src/doc/high_level_api.rst
@@ -2,15 +2,14 @@ High Level API
 ==============
 
 In addition to the old standard pylib API, new versions of pylib ship
-with a high level API that facilitates usage of CaosDB entities within
+with a high level API that facilitates usage of LinkAhead entities within
 data analysis scripts. In a nutshell that API exposes all properties of
-CaosDB Records as standard python attributes making their access easier.
+LinkAhead Records as standard python attributes making their access easier.
 
 Or to speak it out directly in Python:
 
 .. code:: python
 
-
    import caosdb as db
    # Old API:
    r = db.Record()
@@ -50,10 +49,10 @@ practical shorthands:
    return it as high level entity.
 -  ``create_entity_container``: Convert a high level entity into a
    standard entity including all sub entities.
--  ``query``: Do a CaosDB query and return the result as a container of
+-  ``query``: Do a LinkAhead query and return the result as a container of
    high level objects.
 
-So as a first example, you could retrieve any record from CaosDB and use
+So as a first example, you could retrieve any record from LinkAhead and use
 it using its high level representation:
 
 .. code:: python
@@ -87,12 +86,12 @@ series of commands to achieve the same result:
 
 Resolving subproperties makes use of the "resolve\ :sub:`reference`"
 function provided by the high level entity class
-(``CaosDBPythonEntity``), with the following parameters:
+(``LinkAheadPythonEntity``), with the following parameters:
 
 -  ``deep``: Whether to use recursive retrieval
 -  ``references``: Whether to use the supplied db.Container to resolve
    references. This allows offline usage. Set it to None if you want to
-   automatically retrieve entities from the current CaosDB connection.
+   automatically retrieve entities from the current LinkAhead connection.
 -  ``visited``: Needed for recursion, set this to None.
 
 Objects in the high level representation can be serialized to a simple
@@ -125,35 +124,35 @@ beetween the high level and the standard representation.
 The high level entities are represented using the following classes from
 the module ``caosdb.high_level_api``:
 
--  ``CaosDBPythonEntity``: Base class of the following entity classes.
--  ``CaosDBPythonRecord``
--  ``CaosDBPythonRecordType``
--  ``CaosDBPythonProperty``
--  ``CaosDBPythonMultiProperty``: **WARNING** Not implemented yet.
--  ``CaosDBPythonFile``: Used for file entities and provides an
+-  ``LinkAheadPythonEntity``: Base class of the following entity classes.
+-  ``LinkAheadPythonRecord``
+-  ``LinkAheadPythonRecordType``
+-  ``LinkAheadPythonProperty``
+-  ``LinkAheadPythonMultiProperty``: **WARNING** Not implemented yet.
+-  ``LinkAheadPythonFile``: Used for file entities and provides an
    additional ``download`` function for being able to directly retrieve
-   files from CaosDB.
+   files from LinkAhead.
 
 In addition, there are the following helper structures which are
 realized as Python data classes:
 
--  ``CaosDBPropertyMetaData``: For storing meta data about properties.
--  ``CaosDBPythonUnresolved``: The base class of unresolved "things".
--  ``CaosDBPythonUnresolvedParent``: Parents of entities are stored as
+-  ``LinkAheadPropertyMetaData``: For storing meta data about properties.
+-  ``LinkAheadPythonUnresolved``: The base class of unresolved "things".
+-  ``LinkAheadPythonUnresolvedParent``: Parents of entities are stored as
    unresolved parents by default, storing an id or a name of a parent
    (or both).
--  ``CaosDBPythonUnresolvedReference``: An unresolved reference is a
+-  ``LinkAheadPythonUnresolvedReference``: An unresolved reference is a
    reference property with an id which has not (yet) been resolved to an
    Entity.
 
 The function "resolve\ :sub:`references`" can be used to recursively
-replace ``CaosDBPythonUnresolvedReferences`` into members of type
-``CaosDBPythonRecords`` or ``CaosDBPythonFile``.
+replace ``LinkAheadPythonUnresolvedReferences`` into members of type
+``LinkAheadPythonRecords`` or ``LinkAheadPythonFile``.
 
-Each property stored in a CaosDB record corresponds to:
+Each property stored in a LinkAhead record corresponds to:
 
--  a member attribute of ``CaosDBPythonRecord`` **and**
--  an entry in a dict called "metadata" storing a CaosDBPropertyMetadata
+-  a member attribute of ``LinkAheadPythonRecord`` **and**
+-  an entry in a dict called "metadata" storing a LinkAheadPropertyMetadata
    object with the following information about proeprties:
 
    -  ``unit``
diff --git a/src/doc/index.rst b/src/doc/index.rst
index 7344b6aacdd55fd75f4940d834104faa00c33069..b4ee9ff877a230d467b5d77bee61417e89071ace 100644
--- a/src/doc/index.rst
+++ b/src/doc/index.rst
@@ -1,6 +1,6 @@
 
-Welcome to PyCaosDB's documentation!
-====================================
+Welcome to PyLinkAhead's documentation!
+=======================================
 
 .. toctree::
    :maxdepth: 2
@@ -16,7 +16,7 @@ Welcome to PyCaosDB's documentation!
    Code gallery <gallery/index>
    API documentation<_apidoc/caosdb>
 
-This is the documentation for the Python client library for CaosDB, ``PyCaosDB``.
+This is the documentation for the Python client library for LinkAhead, ``PyLinkAhead``.
 
 This documentation helps you to :doc:`get started<README_SETUP>`, explains the most important
 :doc:`concepts<concepts>` and offers a range of :doc:`tutorials<tutorials/index>`.
diff --git a/src/doc/tutorials/Data-Insertion.rst b/src/doc/tutorials/Data-Insertion.rst
index 82df07691f7c78a2787d67463ca222d2e68249ca..a947b27ed8e109e34d7f0896a44ea51b222f242a 100644
--- a/src/doc/tutorials/Data-Insertion.rst
+++ b/src/doc/tutorials/Data-Insertion.rst
@@ -4,12 +4,12 @@ Data Insertion
 Data Models
 ~~~~~~~~~~~
 
-Data is stored and structured in CaosDB using a concept of RecordTypes, Properties, Records etc. If
-you do not know what these are, please look at the chapter :doc:`Data
-Model<caosdb-server:Data-Model>` in the CaosDB server documentation.
+Data is stored and structured in LinkAhead using a concept of RecordTypes, Properties, Records etc.
+If you do not know what these are, please look at the chapter :doc:`Data
+Model<caosdb-server:Data-Model>` in the LinkAhead server documentation.
 
 In order to insert some actual data, we need to create a data model
-using RecordTypes and Properties (You may skip this if you use a CaosDB
+using RecordTypes and Properties (You may skip this if you use a LinkAhead
 instance that already has the required types). When you create a new Property 
 you must supply a datatype. So, let’s create a simple
 Property called “a” of datatype double. This is very easy in pylib:
@@ -65,13 +65,13 @@ all properties of the parent RecordType with the chosen importance (and properti
 importance) to the child RecordType
 automatically upon insertion. See the chapter on `importance
 <https://docs.indiscale.com/caosdb-server/specification/RecordType.html#importance>`_ in the
-documentation of the CaosDB server for more information on the importance and inheritance of
+documentation of the LinkAhead server for more information on the importance and inheritance of
 properties.
 
 .. note::
 
    The inherited properties will only be visible after the insertion since they are set by the
-   CaosDB server, not by the Python client.
+   LinkAhead server, not by the Python client.
 
 
 Insert Actual Data
@@ -111,7 +111,7 @@ record as its source data. Since we know that the id of the experiment record is
 
 The experiment record's id is used as the value of the ``Experiment`` property
 of the analysis Record (note how we use the RecordType ``Experiment`` as a
-``REFERENCE`` property here). Sending a CaosDB query like ``FIND RECORD
+``REFERENCE`` property here). Sending a LinkAhead query like ``FIND RECORD
 Experiment WHICH IS REFERENCED BY A Analysis WITH date=2020-01-08`` would now
 return our original experiment record.
 
@@ -141,7 +141,7 @@ Finally, we can also insert both records at the same time using a
 
    cont = db.Container().extend([rec, ana]) # Add experiment and analysis
                                             # records to our container
-   cont.insert() # Insert both at the same time, the CaosDB server will
+   cont.insert() # Insert both at the same time, the LinkAhead server will
                  # resolve the reference upon insertion.
 
 All three ways result in an Analysis record which references an Experiment
diff --git a/src/doc/tutorials/Entity-Getters.rst b/src/doc/tutorials/Entity-Getters.rst
index 50ed13201e5720de22bf0b605bc5162834a458a8..5bcc97fb7ef097cfa8463e9736ee891152e55559 100644
--- a/src/doc/tutorials/Entity-Getters.rst
+++ b/src/doc/tutorials/Entity-Getters.rst
@@ -2,7 +2,7 @@
 Entity Getters
 ==============
 
-There is a very frequent situation when working with PyCaosDB: You need to get a specific Entity
+There is a very frequent situation when working with PyLinkAhead: You need to get a specific Entity
 from the remote server. For example, you need the Property Entity in order to make an update. Sure,
 you can do a ``db.Entity().retrieve()`` or submit a query, but there is an even faster way which
 also helps preventing errors:
diff --git a/src/doc/tutorials/basic_analysis.rst b/src/doc/tutorials/basic_analysis.rst
index c40cad28b8c9a3be537c641b9614da2eb4df8dd9..a0a91373b440647c8d6a231cabda90ee241a5855 100644
--- a/src/doc/tutorials/basic_analysis.rst
+++ b/src/doc/tutorials/basic_analysis.rst
@@ -11,7 +11,7 @@ If you have not yet, configure a connection with the demo instance. E.g.:
 ...    username="admin", 
 ...    password="caosdb")
 
-A basic Analysis of data in CaosDB could start like:
+A basic Analysis of data in LinkAhead could start like:
 
 >>> 
 >>> analyses =  db.execute_query("FIND RECORD Analysis with quality_factor")
diff --git a/src/doc/tutorials/caching.rst b/src/doc/tutorials/caching.rst
index aad9a1ddbd9e93a3cd06887eaffcf956c3c5bea6..da775c4181c1385756af09f3191a2428923dd616 100644
--- a/src/doc/tutorials/caching.rst
+++ b/src/doc/tutorials/caching.rst
@@ -21,7 +21,7 @@ function, easily created from ``get_entity_by_name`` using Python's ``lru_cache`
    # reset the cache with
    cached_get_by_name.cache_clear()
 
-For convenience, PyCaosDB provides the ``caosdb.cached`` module that defines the functions
+For convenience, PyLinkAhead provides the ``caosdb.cached`` module that defines the functions
 ``cached_query`` and ``cached_get_entity_by``, they use a shared cache. Let's have a look:
 
 .. code:: python
diff --git a/src/doc/tutorials/complex_data_models.rst b/src/doc/tutorials/complex_data_models.rst
index 7b45b6a2681bcf781fd4acc9329ffada28d4e01c..cb9943c21cf365aee6fda86f5743c528f643dc54 100644
--- a/src/doc/tutorials/complex_data_models.rst
+++ b/src/doc/tutorials/complex_data_models.rst
@@ -1,7 +1,7 @@
 Complex Data Models
 -------------------
 
-With CaosDB it is possible to create very complex data models.
+With LinkAhead it is possible to create very complex data models.
 
 E.g. it is possible to add properties to properties to cover complex relations
 in data management workflows.
diff --git a/src/doc/tutorials/data-model-interface.md b/src/doc/tutorials/data-model-interface.md
index f6967c57a0a3de6e7c6fd3d2b64d3f59620526de..97cd560e4b4b3162946f87ee1cea5804b16bb342 100644
--- a/src/doc/tutorials/data-model-interface.md
+++ b/src/doc/tutorials/data-model-interface.md
@@ -8,12 +8,12 @@ pip3 install --user --no-deps .
 ```
 in 
 ```bash
-CaosDB/data_models
+LinkAhead/data_models
 ```
 
 Change to the appropriate directory
 ```bash
-cd CaosDB/data_models
+cd LinkAhead/data_models
 ```
 There are "data models" defined in 
 ```bash
diff --git a/src/doc/tutorials/errors.rst b/src/doc/tutorials/errors.rst
index 37c53c9b527a0435f9f24ae6c6e71687e73eb963..4da41d9dbf6d11cda7752f2687e4eab89816b529 100644
--- a/src/doc/tutorials/errors.rst
+++ b/src/doc/tutorials/errors.rst
@@ -3,9 +3,9 @@ Error Handling
 ==============
 
 In case of erroneous transactions, connection problems and a lot of
-other cases, PyCaosDB may raise specific errors in order to pinpoint
+other cases, PyLinkAhead may raise specific errors in order to pinpoint
 the problem as precisely as possible. Some of these errors a
-representations of errors in the CaosDB server, others stem from
+representations of errors in the LinkAhead server, others stem from
 problems that occurred on the client side.
 
 The errors and exceptions are ordered hierarchically form the most
@@ -16,20 +16,20 @@ following. For more information on specific error types, see also the
 
 .. note::
 
-   Starting from PyCaosDB 0.5, the error handling has changed
+   Starting from PyLinkAhead 0.5, the error handling has changed
    significantly. New error classes have been introduced and the
    behavior of ``TransactionError`` and ``EntityError`` has been
    re-worked. In the following, only the "new" errors are
-   discussed. Please refer to the documentation of PyCaosDB 0.4.1 and
+   discussed. Please refer to the documentation of PyLinkAhead 0.4.1 and
    earlier for the old error handling.
 
-CaosDBException
-----------------
+LinkAheadException
+------------------
 
-``CaosDBException`` is the most generic exception and all other error classes inherit
+``LinkAheadException`` is the most generic exception and all other error classes inherit
 from this one. Because of its generality, it doesn't tell you much
-except that some component of PyCaosDB raised an exception. If you
-want to catch all possible CaosDB errors, this is the class to use.
+except that some component of PyLinkAhead raised an exception. If you
+want to catch all possible LinkAhead errors, this is the class to use.
 
 TransactionError
 ----------------
@@ -116,7 +116,7 @@ HTTP Errors
 -----------
 
 An ``HTTPClientError`` or an ``HTTPServerError`` is raised in case of
-http(s) connection problems caused by the Python client or the CaosDB
+http(s) connection problems caused by the Python client or the LinkAhead
 server, respectively. There are the following subclasses of
 ``HTTPClientError`` that are used to specify the connection problem:
 
@@ -130,7 +130,7 @@ server, respectively. There are the following subclasses of
 Other Errors
 ------------
 
-There are further subclasses of ``CaosDBException`` that are raised in
+There are further subclasses of ``LinkAheadException`` that are raised in
 case of faulty configurations or other problems. They should be rather
 self-explanatory from their names; see the :doc:`source code<../_apidoc/caosdb.exceptions>`
 for further information.
diff --git a/src/doc/tutorials/first_steps.rst b/src/doc/tutorials/first_steps.rst
index c84ec52aa63f0563b22c698081e89600c7af6122..dc19c7306cc32e779024ee1232311d561b12d527 100644
--- a/src/doc/tutorials/first_steps.rst
+++ b/src/doc/tutorials/first_steps.rst
@@ -1,12 +1,12 @@
 First Steps
 ===========
 
-You should have a working connection to a CaosDB instance now. If not, please check out the 
+You should have a working connection to a LinkAhead instance now. If not, please check out the
 :doc:`Getting Started secton</README_SETUP>`.
 
-If you are not yet familiar with Records, RecordTypes and Properties used in CaosDB,
+If you are not yet familiar with Records, RecordTypes and Properties used in LinkAhead,
 please check out the respective part in the `Web Interface tutorial`_.
-You should also know the basics of the CaosDB Query Language (a tutorial is
+You should also know the basics of the LinkAhead Query Language (a tutorial is
 `here <https://docs.indiscale.com/caosdb-webui/tutorials/query.html>`_).
 
 We recommend that you connect to the `demo instance`_ (hosted by `Indiscale`_) in order to try out
@@ -120,7 +120,7 @@ If the files are large data files, it is often a better idea to only retrieve th
 Summary
 -------
 
-Now you know how to use Python to send queries to CaosDB and you can access
+Now you know how to use Python to send queries to LinkAhead and you can access
 the result Records and their properties. 
 
 The next tutorial shows how to make some meaningful use of this.
diff --git a/src/doc/tutorials/index.rst b/src/doc/tutorials/index.rst
index ce37993d7ec5e0888da8a2b4c58904bcbdc43bb4..706e26c2b1b4876c29d43c2bddd9a5fe357a003d 100644
--- a/src/doc/tutorials/index.rst
+++ b/src/doc/tutorials/index.rst
@@ -1,6 +1,6 @@
 
-PyCaosDB Tutorials
-==================
+PyLinkAhead Tutorials
+=====================
 
 This chapter contains tutorials that lead you from the first steps to 
 advanced usage of the Python client.
diff --git a/src/doc/tutorials/serverside.rst b/src/doc/tutorials/serverside.rst
index 93f0fdcf742efc70bc80f5113eb7c6ddbbf87cde..f269dadae58cb3ba3842c732d819ab72bad5aa3a 100644
--- a/src/doc/tutorials/serverside.rst
+++ b/src/doc/tutorials/serverside.rst
@@ -3,7 +3,7 @@ Server Side Scripting
 =====================
 
 The administrator may store regularly needed scripts, e.g. for computing a
-standardized analysis, on the same machine as the CaosDB server, "on the server
+standardized analysis, on the same machine as the LinkAhead server, "on the server
 side", where they can be run directly by the server.
 
 The execution of those scripts can be initiated using the Python client, or the
@@ -29,7 +29,7 @@ script (``stderr`` and ``stdout``) is returned within an response object.
 If the script requires additional arguments, those can be provided after the 
 script's name.
 
-Note that by default the script runs with your CaosDB account. It has your
+Note that by default the script runs with your LinkAhead account. It has your
 permissions and changes are logged as if they were done by you directly.
 
 
@@ -37,7 +37,7 @@ Testing it
 ~~~~~~~~~~
 
 You can try this out using for example the ``diagnostics.py`` script (it is part
-of the `CaosDB server repository
+of the `LinkAhead server repository
 <https://gitlab.indiscale.com/caosdb/src/caosdb-server/-/blob/main/scripting/bin/administration/diagnostics.py>`_
 and is also available on https://demo.indiscale.com). The script returns
 information about the server in JSON format. You can do for example the
diff --git a/src/doc/gallery/simulation.py b/src/doc/gallery/simulation.py
index 342d5d980fc2b1a981f4a76d99e1954f8b2f5c2a..6ba284f727aa5c82c76e0c5165a3490c5671871b 100644
--- a/src/doc/gallery/simulation.py
+++ b/src/doc/gallery/simulation.py
@@ -1,5 +1,5 @@
 """
-Run a simulation and store the values into CaosDB.
+Run a simulation and store the values into LinkAhead.
 
 >>> main()              # doctest: +ELLIPSIS
 These distances resulted in small x,y, values:
@@ -13,7 +13,7 @@ from caosadvancedtools.table_converter import to_table
 
 
 def setup_caosdb():
     """Create the data model and insert it into CaosDB
 
     The data model consists of the following RecordTypes:
 
@@ -35,7 +35,7 @@ def setup_caosdb():
     The data model of course also contains the corresponding properties for these RecordTypes.
     """
 
-    cont = db.Container()  # Container to insert all Entities at once into CaosDB
+    cont = db.Container()  # Container to insert all Entities at once into LinkAhead
     # create Properties
     cont.append(db.Property("x", datatype=db.DOUBLE))
     cont.append(db.Property("y", datatype=db.DOUBLE))
@@ -74,7 +74,7 @@ def simulations(n, t_max):
         # Get the parameters and result
         initial, result = run_simulation(run=i, t_max=t_max)
 
-        # Prepare CaosDB insertion
+        # Prepare LinkAhead insertion
         run = db.Record().add_parent("SoftwareRun").add_property("Software", value=software.id)
         parameters = (db.Record().add_parent("Parameters").add_property("x", initial[0])
                       .add_property("y", initial[1]).add_property("z", initial[2]))
@@ -83,7 +83,7 @@ def simulations(n, t_max):
         run.add_property("Parameters", value=parameters).add_property("Result", value=result_record)
         cont = db.Container()
         cont.extend([run, parameters, result_record])
-        cont.insert()           # Insert everything of this run into CaosDB.
+        cont.insert()           # Insert everything of this run into LinkAhead.
 
 
 def run_simulation(run, t_max):
@@ -13,7 +13,7 @@ from caosadvancedtools.table_converter import to_table
 
 def setup_caosdb():
-    """Create the data model and insert it into CaosDB
+    """Create the data model and insert it into LinkAhead
 
     The data model consists of the following RecordTypes: